@@ -10,11 +10,11 @@ Text::JSON::Nibble - Nibble complete JSON objects from buffers
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS 
@@ -260,7 +260,7 @@ sub proc {
 			return ( join('',@jsonArray[0..$arrayPlace]), $arrayPlace );
 		} else {
 			# Add the complete object to the queue
-			push( @{$self->{jsonqueue}}, join('',@jsonArray[0..$arrayPlace]) );
+			push( @{$self->{jsonqueue}}, substr($self->{buffer},0,$arrayPlace) );
 		
 			# Adjust the buffer
 			$self->{buffer} = substr($self->{buffer},$arrayPlace+1);
